@@ -3,8 +3,9 @@ package Data::Mining::Apriori;
 use 5.010001;
 use strict;
 use warnings;
+no if $] >= 5.017011, warnings => 'experimental::smartmatch';
 
-our $VERSION = 0.02;
+our $VERSION = 0.03;
 
 my $self;
 
@@ -112,10 +113,9 @@ for(my$subsetSize=0;$subsetSize<$#itemsetCandidate;$subsetSize++){
 	}
 	@subsetLeft = sort @subsetLeft;
 	foreach my$item(@itemsetCandidate){
-		if($item ~~ @subsetLeft){
-			next;
+		if(!($item ~~ @subsetLeft)){
+			push @subsetRight,$item;
 		}
-		push @subsetRight,$item;
 	}
 	@subsetRight = sort @subsetRight;
 	if("@subsetRight" ~~ @{$itemsetSubset{"@subsetLeft"}}){
@@ -148,17 +148,15 @@ for(my$subsetSize=0;$subsetSize<$#itemsetCandidate;$subsetSize++){
 			@{$self->{associationRules}{$self->{rule}}{"R$self->{rule}"}{items}} = ();
 			foreach my$item(@subsetLeft){
 				push @{$self->{associationRules}{$self->{rule}}{"R$self->{rule}"}{items}},$item;
-				if($item ~~ @newItemsetCandidateSizeOne){
-					next;
+				if(!($item ~~ @newItemsetCandidateSizeOne)){
+					push @newItemsetCandidateSizeOne,$item;
 				}
-				push @newItemsetCandidateSizeOne,$item;
 			}
 			foreach my$item(@subsetRight){
 				push @{$self->{associationRules}{$self->{rule}}{"R$self->{rule}"}{items}},$item;
-				if($item ~~ @newItemsetCandidateSizeOne){
-					next;
+				if(!($item ~~ @newItemsetCandidateSizeOne)){
+					push @newItemsetCandidateSizeOne,$item;
 				}
-				push @newItemsetCandidateSizeOne,$item;
 			}
 		}
 	}
@@ -342,7 +340,8 @@ Data::Mining::Apriori - Perl extension for implement the data mining algorithm a
 	$apriori->{itemsKeyDescription}{102}='BREAD';
 	$apriori->{itemsKeyDescription}{'103'}='CEREAL';
 
-	@{$apriori->{itemsKeyTransactions}{'101'}}=('1101',1103,'1104',1105,'1106',1107,'1109',1110); # Reference to array, to add the transactions of each item per key
+	@{$apriori->{itemsKeyTransactions}{'101'}}=('1101',1103,'1104',1105,'1106',1107,'1109',1110);
+	# Reference to array, to add the transactions of each item per key
 	@{$apriori->{itemsKeyTransactions}{102}}=('1102',1103,'1104',1105,'1106',1107,1108,'1109',1110);
 	@{$apriori->{itemsKeyTransactions}{'103'}}=('1101',1102,1103,'1104','1106',1107,1108,'1109',1110);
 
